#
# spec file for package python-pylast
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pylast
Version:        5.2.0
Release:        1.3
Summary:        A python interface to Last.fm
License:        Apache-2.0
URL:            https://github.com/pylast/pylast
Source0:        https://files.pythonhosted.org/packages/source/p/pylast/pylast-%{version}.tar.gz
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires:       python-httpx
# SECTION test requirements
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module httpx}
BuildRequires:  %{python_module pyaml}
BuildRequires:  %{python_module pycodestyle}
BuildRequires:  %{python_module pyflakes}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A Python interface to Last.fm and other API-compatible websites such as Libre.fm

Features:
- Simple public interface.
- Access to all the data exposed by the Last.fm webservices.
- Scrobbling support.
- Full object-oriented design.
- Proxy support.
- Internal caching support for some webservices calls (disabled by default).
- No extra dependencies but python itself.
- Support for other API-compatible networks like Libre.fm
- Python3-friendly (Starting from 0.5).

%prep
%setup -q -n pylast-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}/%{python_sitelib}

%check
# every test file has:
# Integration (not unit) tests for pylast.py
# almost all skipped, need internet access
%pytest

%files %{python_files}
%doc README.md
%license COPYING
%dir %{python_sitelib}/pylast
%{python_sitelib}/pylast
%{python_sitelib}/pylast-%{version}.dist-info

%changelog
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 5.2.0:
  * Support for Python 3.12
  * Drop support for EOL Python 3.7
  * Publish to PyPI with a Trusted Publisher
  * Document how to authenticate with a session key
- update to 5.1.0:
  * Support Python 3.11 (#399)
  * Migrate from setuptools + setuptools_scm to hatchling +
    hatch-vcs (#413) @hugovk
- update to 5.0.0:
  * Replace `http.client` with HTTPX (#379) @hugovk
  * Log method names at INFO level, also log API return data at
    DEBUG level
  * Drop support for Python 3.6 (#387) @hugovk
  * Remove deprecated `is_streamable` and
    `is_fulltrack_available` (#388) @hugovk
  * If album has no MBID, `album.get_getmbid()` returns None
* Wed Oct 12 2022 Dirk Müller <dmueller@suse.com>
- drop unneeded six dependency
* Wed Apr  6 2022 pgajdos@suse.com
- pytest-mock is not required for build
* Sat Mar 26 2022 Dirk Müller <dmueller@suse.com>
- update to 4.5.0:
  * Deprecate is_streamable and is_fulltrack_available
  * Strip invalid XML characters from response
  * Speedup: Use faster importlib.metadata for getting version (#377) @hugovk
  * Convert setup.py to static setup.cfg and format with setup-cfg-fmt (#376) @hugovk
  * Rename master to main, use 3.10 final, add workflow_dispatch (#374) @hugovk
  * Set get_top_tracks limit even if it's None, to get unlimited user top_tracks
  * Add support for Python 3.10
  * Fix artist.get_bio_content() when bio is empty + other test fixes (#370) @hugovk
  * Remove artist.shout("<3") in README.md (#369) @tieubinhco
  * Bugfix for get_userloved and get_userplaycount resulting in an empty response from the server
  * Fix unsafe creation of temp file for caching, and improve exception raising (#356) @kvanzuijlen
  * [pre-commit.ci] pre-commit autoupdate (#362) @pre-commit-ci
* Tue Mar 15 2022 Dirk Müller <dmueller@suse.com>
- use python_expand for fdupes
* Mon Feb 22 2021 andy great <andythe_great@pm.me>
- Update to 4.1.0.
  * Added
  * Add support for streaming (#336) @kvanzuijlen
  * Changed
  * Update copyright year (#360) @hugovk
  * Replace Travis CI with GitHub Actions
  * Fixed
  * Set limit to 50 by default, not 1
  * Updates for 4.0.0.
  * Added
  * Add support for Python 3.9.
  * Removed
  * Remove deprecated Artist.get_cover_image,
    User.get_artist_tracks and STATUS_TOKEN_ERROR.
* Fri Aug  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 3.3.0
  * `User.get_now_playing`: Add album and cover image to info (#330) @hugovk
  * Improve handling of error responses from the API (#327) @spiritualized
  * Deprecate `Artist.get_cover_image`, they're no longer available from Last.fm (#332) @hugovk
  * Fix `artist.get_bio_content()` to return `None` if bio is empty (#326) @hugovk
* Fri Mar 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 3.2.1
  * Fix regression calling `get_recent_tracks` with `limit=None` (#320) @hugovk
  * Support for Python 3.8
  * Store album art URLs when you call `GetTopAlbums` ([#307])
  * Retry paging through results on exception ([#297])
  * Respect `get_recent_tracks`' limit when there's a now playing track ([#310])
  * Remove Python 2 warnings, `python_requires` should be enough ([#312])
  * Use setuptools_scm to simplify versioning during release ([#316])
  * Extract username from session via new
  * Drop support for Python 2.7 ([#265])
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Apr 26 2019 pgajdos@suse.com
- version update to 3.1.0
  * Extract username from session via new
    SessionKeyGenerator.get_web_auth_session_key_username (#290)
  * User.get_track_scrobbles (#298)
  * User.get_artist_tracks. Use User.get_track_scrobbles as a
    partial replacement. (#298)
- python3 only package
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon May  8 2017 alarrosa@suse.com
- Use %%python_exec to call %%fdupes separately on each python_sitelib
  directory. Otherwise a symlink from the python3 sitelib directory
  was created to the python2 one, breaking the python3 package when
  the python2 package wasn't installed.
* Thu Apr  6 2017 alarrosa@suse.com
- Converted to singlespec
* Fri Mar 24 2017 alarrosa@suse.com
- update to version 1.8.0:
  * Update error message for test_init_with_token
  * Support authentication tokens to construct networks
  * Update README.md
- update to version 1.7.0:
  * Add python 3.5 and 3.6 tests environments
  * Separate Libre.fm test from Last.fm tests
  * Fix Error message to reference Libre.fm or Last.fm
  * Use default SSL context when possible
  * switch from HTTPConnection to HTTPSConnection
  * Add missing dependency in README, update gitignore for JetBrains
  * Update Libre.fm URL
* Mon May 16 2016 arun@gmx.de
- update to version 1.6.0:
  * Split test into passing and failing tests
  * Skip tests if Last.fm API still broken
  * Include tests in release source tarball
  * Update year
  * pep8 fixes for #153
  * Fix build: no such option: --download-cache
  * Skip more tests which fail due to the (still) broken Last.fm API
  * Skip tests which fail due to the (still) broken Last.fm API
  * x.next() -> next(x) for python3 compat
  * Update __init__.py
  * replaced opensearch: as empty str
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sun Dec 13 2015 arun@gmx.de
- update to version 1.5.1:
  * Fix tox==2.1.1
  * Add YAML rules [CI skip]
  * Fix album.get_tracks()
  * Fix for #146: only get the top-level <mbid>
- changes from version 1.5.0:
  * Check installation sooner [CI skip]
* Sun Sep 27 2015 arun@gmx.de
- update to version 1.4.2
  * (no changelog available)
- changes from version 1.4.0:
  * Fix get_recent_tracks (and more)
- update to version 1.3.0:
  * Let Tox use these env vars
  * get_tagged_tracks: Use cacheable param
  * flake8
  * pep8 compliance
  * Add test case for Track.get_correction()
  * Add test case for Artist.get_correction()
  * Add suppport for track.getCorrection
  * Add suppport for artist.getCorrection
  * Fixed broken comment
  * User.GetPersonalTags bug fix
  * Added User.GetPersonalTags test cases
  * Fixed broken comment
  * Cleanup of User.GetPersonalTags stuff
  * Support for User.GetPersonalTags
  * Remove useless Scrutinizer badge
  * Replace broken pypip.in badges with shields.io
- changes from version 1.2.1:
  * Remember to release on master
  * Update release checklist
* Sun Aug 16 2015 zaitor@opensuse.org
- Add missing python3-six Requires.
* Sat May  9 2015 arun@gmx.de
- update to version 1.2.1 and 1.2.0:
  * Remove unused import
  * Remove artist.getImages and depracation note
  * Remove commented function
  * Retry failures up to four times, require at least one pass
  * Sometimes Last.fm returns an error for dates[1]: No chart available
  for this user/date-range combination
  * Add EditorConfig
  * Don't compare with limit if limit is None. Fixes #124.
  * Failing test for #124
  * 2015
  * Add licence
  * Don't redefine built-in
  * Remove unused argument
  * Badges: master -> develop, hugovk -> pylast
  * Run fast lint job first
  * Remove unused import
  * pep8 fixes
  * Rerun flaky interation tests
  * Release checklist
* Sun Jan 25 2015 arun@gmx.de
- specfile:
  * update copyright year
  * removed modname variable
  * updated source to point to pypi
  * require setuptools
  * no more README in tar-ball, removed it from %%files section
  * update %%files section
- update to version 1.1.0:
  * Fix pytest.py link
  * Update testing instructions [CI skip]
  * Remove unused .build file
  * fix grep filter for clonedigger.
  * remove dir-locals. make clonedigger always exit 0
  * fix base object hasing. Closes  #120 .
  * Version bump, fix setup.py, which was previously broken because excludes was not a tuple, so each character wa
  * Fix UnicodeDecodeError from #114. Replace definitions of _unicode and _string. Add six as a dependeny. Fix clo
  * Skip if PYLAST_USERNAME etc. env vars missing
  * Revert "Add failing test for #114" (This revert should be reverted later as the test from this commit should b
  * Remove duplicate line, Make test_pylast.py runnable as main again.
  * add credentials for IvanMalison/pylast.
  * Add failing test for #114
  * add posargs to tox tests.
  * Get rid of --doctest-modules in py.test command.
  * Consolidate travis environments. separate matrix and global environment variables.
  * Add tox to travis installation.
  * tox/travis stuff. making testing more uniform.
  * Don't encode strings as 'utf-8' twice in _get_cache_key. Closes #109.
  * Make pylast a package. Move tests into a directory. Start using pytest and tox. Use setuptools instead of dist
  * Remove unused import
  * Don't use .build file for minor version because we define the full version in pylast.py as well
  * Fix word in SessionKeyGenerator comment.
  * Fix params
  * Remove asserts which can fail
  * Landscape.io fixes
  * Add pypy3; track coverage in Scrutinizer
  * Use Docker
  * Update pylast.py
  * Make test more robust
  * Badges! [CI skip]
  * Add from/to parameters to get_recent_tracks()
  * Fix chart tests that failed due to date ranges (take 2)
  * Fix chart tests that failed due to date ranges
  * Last.fm returns no results for artist.getsimilar with limit=1, but limit=2 returns 2
  * Fix comparison with None for artist, album and event, with test. For #97.
  * Add artist.get_band_members() with tests
  * Add PyPI version badge
  * Add badge for number of PyPI downloads
  * syntax highlighting in readme
  * Fix opus comparison with None
  * Update install instructions now 1.0.0 is on PyPI
* Mon Aug  4 2014 p.drouand@gmail.com
- Remove conflict with python-pylast; it doesn't exist
* Mon Aug  4 2014 malcolmlewis@opensuse.org
- Initial build.
